Re: [PATCH v2 1/3] TI81XX: Prepare for addition of TI814X support

2011-09-22 Thread Tony Lindgren
* Pedanekar, Hemant hema...@ti.com [110921 17:00]:
 Tony Lindgren wrote on Thursday, September 22, 2011 2:11 AM:
 
  * Hemant Pedanekar hema...@ti.com [110921 10:05]:
  --- a/arch/arm/mach-omap2/board-ti8168evm.c
  +++ b/arch/arm/mach-omap2/board-ti8168evm.c
  @@ -37,16 +37,16 @@ static void __init ti8168_evm_init(void)
  
   static void __init ti8168_evm_map_io(void)
   {
  -  omap2_set_globals_ti816x();
  -  omapti816x_map_common_io();
  +  omap2_set_globals_ti81xx();
  +  omapti81xx_map_common_io();
   }
  
   MACHINE_START(TI8168EVM, ti8168evm)
 /* Maintainer: Texas Instruments */
 .atag_offset= 0x100,
 .map_io = ti8168_evm_map_io,
  -  .init_early = ti816x_init_early,
  -  .init_irq   = ti816x_init_irq,
  +  .init_early = ti81xx_init_early,
  +  .init_irq   = ti81xx_init_irq,
 .timer  = omap3_timer,
 .init_machine   = ti8168_evm_init,
   MACHINE_END
  
  Looks like you still need a minor rebase on the current cleanup
  branch as the ti8668_evm_map_io is no longer needed. The cleanup
  branch already has Paul's CHIP_IS removal, so that should be trivial.
 
 
 Tony,
 Can you please clarify? Do we not need ti8168_evm_map_io() for global data
 initianlization and io init? Or, as you mentioned in comment on 3/3 of the
 series, do you mean to rename this with ti81xx and move to common.c?

Yes just have a generic one in common.c should be enough. Sorry I thought
that was already done, but looks like it was only done for omap3_map_io.
  
  Ideally the rename patch would be separate without any functional
  changes, maybe you can move the changes and additions to the next patch?
  
  Tony
 
 If the above understanding is correct, then I will just have to rename+move
 ti8168_evm_map_io() so the change can still be in this patch, right? Or are
 You referring to any other part which should not be in this patch?

Yes it's OK to keep it in this patch.

Tony
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


RE: [PATCH v2 1/3] TI81XX: Prepare for addition of TI814X support

2011-09-22 Thread Pedanekar, Hemant
Tony Lindgren wrote on Thursday, September 22, 2011 11:51 PM:

 * Pedanekar, Hemant hema...@ti.com [110921 17:00]:
 Tony Lindgren wrote on Thursday, September 22, 2011 2:11 AM:
 
 * Hemant Pedanekar hema...@ti.com [110921 10:05]:
 --- a/arch/arm/mach-omap2/board-ti8168evm.c
 +++ b/arch/arm/mach-omap2/board-ti8168evm.c
 @@ -37,16 +37,16 @@ static void __init ti8168_evm_init(void)
 
  static void __init ti8168_evm_map_io(void)
  {
 -  omap2_set_globals_ti816x();
 -  omapti816x_map_common_io();
 +  omap2_set_globals_ti81xx();
 +  omapti81xx_map_common_io();
  }
 
  MACHINE_START(TI8168EVM, ti8168evm)
/* Maintainer: Texas Instruments */
.atag_offset= 0x100,
.map_io = ti8168_evm_map_io,
 -  .init_early = ti816x_init_early,
 -  .init_irq   = ti816x_init_irq,
 +  .init_early = ti81xx_init_early,
 +  .init_irq   = ti81xx_init_irq,
.timer  = omap3_timer,
.init_machine   = ti8168_evm_init,
  MACHINE_END
 
 Looks like you still need a minor rebase on the current cleanup
 branch as the ti8668_evm_map_io is no longer needed. The cleanup
 branch already has Paul's CHIP_IS removal, so that should be trivial.
 
 
 Tony,
 Can you please clarify? Do we not need ti8168_evm_map_io() for global data
 initianlization and io init? Or, as you mentioned in comment on 3/3 of the
 series, do you mean to rename this with ti81xx and move to common.c?
 
 Yes just have a generic one in common.c should be enough. Sorry I thought
 that was already done, but looks like it was only done for omap3_map_io.
 
 Ideally the rename patch would be separate without any functional
 changes, maybe you can move the changes and additions to the next patch?
 
 Tony
 
 If the above understanding is correct, then I will just have to rename+move
 ti8168_evm_map_io() so the change can still be in this patch, right? Or are
 You referring to any other part which should not be in this patch?
 
 Yes it's OK to keep it in this patch.
 
 Tony

Thanks. I will send updated version.

   Hemant--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


[PATCH v2 1/3] TI81XX: Prepare for addition of TI814X support

2011-09-21 Thread Hemant Pedanekar
This patch updates existing macros, functions used for TI816X, to enable
addition of other SoCs belonging to TI81XX family (e.g., TI814X).

The approach taken is to use TI81XX/ti81xx for code/data going to be common
across all TI81XX devices.

cpu_is_ti81xx() is introduced to handle code common across TI81XX devices.

Signed-off-by: Hemant Pedanekar hema...@ti.com
---
 arch/arm/mach-omap2/Kconfig|6 ++--
 arch/arm/mach-omap2/board-ti8168evm.c  |8 +++---
 arch/arm/mach-omap2/clock3xxx_data.c   |2 +-
 arch/arm/mach-omap2/common.c   |   22 ++--
 arch/arm/mach-omap2/control.h  |8 +++---
 arch/arm/mach-omap2/id.c   |8 +++---
 arch/arm/mach-omap2/include/mach/debug-macro.S |   12 +-
 arch/arm/mach-omap2/include/mach/entry-macro.S |4 +-
 arch/arm/mach-omap2/io.c   |   12 +-
 arch/arm/mach-omap2/irq.c  |2 +-
 arch/arm/mach-omap2/serial.c   |6 ++--
 arch/arm/plat-omap/include/plat/common.h   |4 +-
 arch/arm/plat-omap/include/plat/cpu.h  |   13 +++
 arch/arm/plat-omap/include/plat/hardware.h |2 +-
 arch/arm/plat-omap/include/plat/io.h   |6 ++--
 arch/arm/plat-omap/include/plat/irqs.h |2 +-
 arch/arm/plat-omap/include/plat/serial.h   |   14 ++--
 .../plat-omap/include/plat/{ti816x.h = ti81xx.h}  |   18 
 arch/arm/plat-omap/include/plat/uncompress.h   |8 +++---
 arch/arm/plat-omap/io.c|2 +-
 20 files changed, 86 insertions(+), 73 deletions(-)
 rename arch/arm/plat-omap/include/plat/{ti816x.h = ti81xx.h} (60%)

diff --git a/arch/arm/mach-omap2/Kconfig b/arch/arm/mach-omap2/Kconfig
index 7edf802..a3b9227 100644
--- a/arch/arm/mach-omap2/Kconfig
+++ b/arch/arm/mach-omap2/Kconfig
@@ -73,8 +73,8 @@ config SOC_OMAP3430
default y
select ARCH_OMAP_OTG
 
-config SOC_OMAPTI816X
-   bool TI816X support
+config SOC_OMAPTI81XX
+   bool TI81XX support
depends on ARCH_OMAP3
default y
 
@@ -313,7 +313,7 @@ config MACH_OMAP_3630SDP
 
 config MACH_TI8168EVM
bool TI8168 Evaluation Module
-   depends on SOC_OMAPTI816X
+   depends on SOC_OMAPTI81XX
default y
 
 config MACH_OMAP_4430SDP
diff --git a/arch/arm/mach-omap2/board-ti8168evm.c 
b/arch/arm/mach-omap2/board-ti8168evm.c
index e26c79c..e0c7300 100644
--- a/arch/arm/mach-omap2/board-ti8168evm.c
+++ b/arch/arm/mach-omap2/board-ti8168evm.c
@@ -37,16 +37,16 @@ static void __init ti8168_evm_init(void)
 
 static void __init ti8168_evm_map_io(void)
 {
-   omap2_set_globals_ti816x();
-   omapti816x_map_common_io();
+   omap2_set_globals_ti81xx();
+   omapti81xx_map_common_io();
 }
 
 MACHINE_START(TI8168EVM, ti8168evm)
/* Maintainer: Texas Instruments */
.atag_offset= 0x100,
.map_io = ti8168_evm_map_io,
-   .init_early = ti816x_init_early,
-   .init_irq   = ti816x_init_irq,
+   .init_early = ti81xx_init_early,
+   .init_irq   = ti81xx_init_irq,
.timer  = omap3_timer,
.init_machine   = ti8168_evm_init,
 MACHINE_END
diff --git a/arch/arm/mach-omap2/clock3xxx_data.c 
b/arch/arm/mach-omap2/clock3xxx_data.c
index dadb8c6..6054654 100644
--- a/arch/arm/mach-omap2/clock3xxx_data.c
+++ b/arch/arm/mach-omap2/clock3xxx_data.c
@@ -3576,7 +3576,7 @@ int __init omap3xxx_clk_init(void)
 * Lock DPLL5 -- here only until other device init code can
 * handle this
 */
-   if (!cpu_is_ti816x()  (omap_rev() = OMAP3430_REV_ES2_0))
+   if (!cpu_is_ti81xx()  (omap_rev() = OMAP3430_REV_ES2_0))
omap3_clk_lock_dpll5();
 
/* Avoid sleeping during omap3_core_dpll_m2_set_rate() */
diff --git a/arch/arm/mach-omap2/common.c b/arch/arm/mach-omap2/common.c
index 3f20cbb..7ce80f2 100644
--- a/arch/arm/mach-omap2/common.c
+++ b/arch/arm/mach-omap2/common.c
@@ -101,23 +101,23 @@ void __init omap3_map_io(void)
 
 /*
  * Adjust TAP register base such that omap3_check_revision accesses the correct
  * TI816X register for checking device ID (it adds 0x204 to tap base while
  * TI816X DEVICE ID register is at offset 0x600 from control base).
  */
-#define TI816X_TAP_BASE(TI816X_CTRL_BASE + \
-   TI816X_CONTROL_DEVICE_ID - 0x204)
+#define TI81XX_TAP_BASE(TI81XX_CTRL_BASE + \
+   TI81XX_CONTROL_DEVICE_ID - 0x204)
 
-static struct omap_globals ti816x_globals = {
+static struct omap_globals ti81xx_globals = {
.class  = OMAP343X_CLASS,
-   .tap= 
@@ -101,23 +101,23 @@ void __init omap3_map_io(void)
 /*
  * Adjust TAP register base such that omap3_check_revision accesses the correct
- * TI816X register for checking device ID (it adds 0x204 to tap base while
- * TI816X DEVICE ID register is at offset 0x600 from control base).
+ * TI81XX register for checking device ID (it adds 0x204 to tap base while
+ * TI81XX DEVICE ID register is at offset 0x600 from control base).
  */

Re: [PATCH v2 1/3] TI81XX: Prepare for addition of TI814X support

2011-09-21 Thread Tony Lindgren
* Hemant Pedanekar hema...@ti.com [110921 10:05]:
 --- a/arch/arm/mach-omap2/board-ti8168evm.c
 +++ b/arch/arm/mach-omap2/board-ti8168evm.c
 @@ -37,16 +37,16 @@ static void __init ti8168_evm_init(void)
  
  static void __init ti8168_evm_map_io(void)
  {
 - omap2_set_globals_ti816x();
 - omapti816x_map_common_io();
 + omap2_set_globals_ti81xx();
 + omapti81xx_map_common_io();
  }
  
  MACHINE_START(TI8168EVM, ti8168evm)
   /* Maintainer: Texas Instruments */
   .atag_offset= 0x100,
   .map_io = ti8168_evm_map_io,
 - .init_early = ti816x_init_early,
 - .init_irq   = ti816x_init_irq,
 + .init_early = ti81xx_init_early,
 + .init_irq   = ti81xx_init_irq,
   .timer  = omap3_timer,
   .init_machine   = ti8168_evm_init,
  MACHINE_END

Looks like you still need a minor rebase on the current cleanup
branch as the ti8668_evm_map_io is no longer needed. The cleanup
branch already has Paul's CHIP_IS removal, so that should be
trivial.

Ideally the rename patch would be separate without any functional
changes, maybe you can move the changes and additions to the next
patch?

Tony
--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html


RE: [PATCH v2 1/3] TI81XX: Prepare for addition of TI814X support

2011-09-21 Thread Pedanekar, Hemant
Tony Lindgren wrote on Thursday, September 22, 2011 2:11 AM:

 * Hemant Pedanekar hema...@ti.com [110921 10:05]:
 --- a/arch/arm/mach-omap2/board-ti8168evm.c
 +++ b/arch/arm/mach-omap2/board-ti8168evm.c
 @@ -37,16 +37,16 @@ static void __init ti8168_evm_init(void)
 
  static void __init ti8168_evm_map_io(void)
  {
 -omap2_set_globals_ti816x();
 -omapti816x_map_common_io();
 +omap2_set_globals_ti81xx();
 +omapti81xx_map_common_io();
  }
 
  MACHINE_START(TI8168EVM, ti8168evm)
  /* Maintainer: Texas Instruments */
  .atag_offset= 0x100,
  .map_io = ti8168_evm_map_io,
 -.init_early = ti816x_init_early,
 -.init_irq   = ti816x_init_irq,
 +.init_early = ti81xx_init_early,
 +.init_irq   = ti81xx_init_irq,
  .timer  = omap3_timer,
  .init_machine   = ti8168_evm_init,
  MACHINE_END
 
 Looks like you still need a minor rebase on the current cleanup
 branch as the ti8668_evm_map_io is no longer needed. The cleanup
 branch already has Paul's CHIP_IS removal, so that should be trivial.


Tony,
Can you please clarify? Do we not need ti8168_evm_map_io() for global data
initianlization and io init? Or, as you mentioned in comment on 3/3 of the
series, do you mean to rename this with ti81xx and move to common.c?
 
 Ideally the rename patch would be separate without any functional
 changes, maybe you can move the changes and additions to the next patch?
 
 Tony

If the above understanding is correct, then I will just have to rename+move
ti8168_evm_map_io() so the change can still be in this patch, right? Or are
You referring to any other part which should not be in this patch?

Thanks.
 
   Hemant--
To unsubscribe from this list: send the line unsubscribe linux-omap in
the body of a message to majord...@vger.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html